#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""
Tests for vela.emulators
"""
import logging
from unittest.mock import patch

import pytest
from vela.emulators import CasaEmulator


class TestCasaEmulator:
    @pytest.mark.skip("Ignores forger mock.")
    @patch("os.chdir")
    @patch("vela.forger.VelaProduct.forge_products")
    @patch("vela.forger.VelaLog.forge_logs")
    def test_run(self, mock_logs, mock_products, mock_os):
        with patch("vela.forger.forge") as mock_forge:
            CasaEmulator("test/test.json", "test/PPR.xml", "standard_cal").run()
            assert mock_forge.call_count == 1

    @patch("glob.glob")
    @patch("os.chdir")
    @patch("os.getcwd")
    def test_check_logs_cal(self, mock_cwd, mock_chdir, mock_glob, caplog):
        caplog.set_level(logging.INFO)
        # shouldn't run for std cals
        CasaEmulator("test.json", "PPR.xml", "standard_cal").check_logs()
        assert mock_glob.call_count == 0
        assert "CHECKING VELA LOGS!" not in caplog.text

    @patch("glob.glob")
    @patch("os.chdir")
    @patch("os.getcwd")
    def test_check_logs_restore_pass(self, mock_cwd, mock_chdir, mock_glob, caplog):
        # should run for restores
        mock_glob.return_value = ["test/vela-12345678-098765.log"]
        caplog.set_level(logging.INFO)
        CasaEmulator("test.json", "PPR.xml", "restore").check_logs()
        assert "CHECKING VELA LOGS!" in caplog.text
        assert "VELA processing complete." in caplog.text

    @patch("sys.exit")
    @patch("glob.glob")
    @patch("os.chdir")
    @patch("os.getcwd")
    def test_check_logs_restore_fail(self, mock_cwd, mock_chdir, mock_glob, mock_exit, caplog):
        # should run for restores
        mock_glob.return_value = ["test/vela-12345678-432109.log"]
        caplog.set_level(logging.INFO)
        CasaEmulator("test.json", "PPR.xml", "restore").check_logs()
        assert "CHECKING VELA LOGS!" in caplog.text
        assert "VELA ERROR! Please inspect logs." in caplog.text
        assert mock_exit.call_count == 1
