"""htc10 workflow fixes

Revision ID: d992b379d8a7
Revises: 36591dc3f14d
Create Date: 2024-02-29 12:37:02.423565

"""
from alembic import op
from pathlib import Path
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = 'd992b379d8a7'
down_revision = '36591dc3f14d'
branch_labels = None
depends_on = None

wf_name = 'pims_split'


# Handle the proper encoding from text -> bytea to not lose any characters
def set_wf_content(filename: str) -> bytes:
    return (Path.cwd() / "versions" / "templates" / wf_name / filename).read_text().encode()


def upgrade():
    conn = op.get_bind()

    # Remove quotes around string variables that have already been quoted
    conn.execute(
        f"""
        UPDATE workflow_templates
        SET content = %s
        WHERE filename = 'split.condor' and workflow_name = E'{wf_name}'
        """,
        set_wf_content("split_condor_2.8.3.txt"),
    )

    # Put back in the update_stage calls that disappeared since 2.8.1
    conn.execute(
        f"""
        UPDATE workflow_templates
        SET content = %s
        WHERE filename = 'restore.sh' and workflow_name = E'{wf_name}'
        """,
        set_wf_content("restore_sh_2.8.3.txt"),
    )

    conn.execute(
        f"""
        UPDATE workflow_templates
        SET content = %s
        WHERE filename = 'split.sh' and workflow_name = E'{wf_name}'
        """,
        set_wf_content("split_sh_2.8.3.txt"),
    )

    conn.execute(
        f"""
        UPDATE workflow_templates
        SET content = %s
        WHERE filename = 'write_finished_file.sh' and workflow_name = E'{wf_name}'
        """,
        set_wf_content("finish_sh_2.8.3.txt"),
    )


def downgrade():
    conn = op.get_bind()

    conn.execute(
        f"""
        UPDATE workflow_templates
        SET content = %s
        WHERE filename = 'split.condor' and workflow_name = E'{wf_name}'
        """,
        set_wf_content("split_condor_2.8.2.txt"),
    )

    conn.execute(
        f"""
        UPDATE workflow_templates
        SET content = %s
        WHERE filename = 'restore.sh' and workflow_name = E'{wf_name}'
        """,
        set_wf_content("restore_sh_2.8.2.txt"),
    )

    conn.execute(
        f"""
        UPDATE workflow_templates
        SET content = %s
        WHERE filename = 'split.sh' and workflow_name = E'{wf_name}'
        """,
        set_wf_content("split_sh_2.8.2.txt"),
    )

    conn.execute(
        f"""
        UPDATE workflow_templates
        SET content = %s
        WHERE filename = 'write_finished_file.sh' and workflow_name = E'{wf_name}'
        """,
        set_wf_content("finish_sh_2.8.2.txt"),
    )
